==> PGObject-Simple-Role-0.70.tar.gz: PGObject-Simple-Role-0.70/README.md <==
PGObject-Simple-Role

PGObject::Simple::Role is a Moo/Moose mapper for minimalist PGObject framework 
(embodied in PGObject::Simple).  Basically it provides a way to easily map 
stored procedures using the conventions of PGObject::Simple for Moo/Moose 
environments.

PGObject::Simple::Role is a Moo role which allows you to use this functionality
in Moo and Moose environments.  The role itself makes no assumptions about 
database state, but provides hooks for classes to use to retrieve or create
database handles for their use.

This module is suited to quick and easy integration of PostgreSQL stored
procedures with Moo and Moose object models.  It is quite powerful and it makes
developing in such environments relatively easy.

INSTALLATION

To install this module, run the following commands:

	perl Makefile.PL
	make
	make test
	make install

SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc PGObject::Simple::Role

You can also look for information at:

    RT, CPAN's request tracker (report bugs here)
        http://rt.cpan.org/NoAuth/Bugs.html?Dist=PGObject-Simple-Role

    AnnoCPAN, Annotated CPAN documentation
        http://annocpan.org/dist/PGObject-Simple-Role

    CPAN Ratings
        http://cpanratings.perl.org/d/PGObject-Simple-Role

    Search CPAN
        http://search.cpan.org/dist/PGObject-Simple-Role/


LICENSE AND COPYRIGHT

Copyright (C) 2013 Chris Travers

Redistribution and use in source and compiled forms with or without 
modification, are permitted provided that the following conditions are met:

*  Redistributions of source code (Perl) must retain the above
   copyright notice, this list of conditions and the following disclaimer as the
   first lines of this file unmodified.

*  Redistributions in compiled form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   source code, documentation, and/or other materials provided with the 
   distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR(S) "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

==> PGObject-Simple-Role-2.1.1.tar.gz: PGObject-Simple-Role-2.1.1/README.md <==
PGObject-Simple-Role

PGObject::Simple::Role is a Moo/Moose mapper for minimalist PGObject framework 
(embodied in PGObject::Simple).  Basically it provides a way to easily map 
stored procedures using the conventions of PGObject::Simple for Moo/Moose 
environments.

PGObject::Simple::Role is a Moo role which allows you to use this functionality
in Moo and Moose environments.  The role itself makes no assumptions about 
database state, but provides hooks for classes to use to retrieve or create
database handles for their use.

This module is suited to quick and easy integration of PostgreSQL stored
procedures with Moo and Moose object models.  It is quite powerful and it makes
developing in such environments relatively easy.

INSTALLATION

To install this module, run the following commands:

    perl Makefile.PL
    make
    make test
    make install

SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc PGObject::Simple::Role

You can also look for information at:

    RT, CPAN's request tracker (report bugs here)
        https://rt.cpan.org/NoAuth/Bugs.html?Dist=PGObject-Simple-Role

    MetaCPAN
        https://metacpan.org/dist/PGObject-Simple-Role


LICENSE AND COPYRIGHT

  Copyright 2013-2017 Chris Travers
  Copyright 2016-2021 The LedgerSMB Core team

Redistribution and use in source and compiled forms with or without 
modification, are permitted provided that the following conditions are met:

*  Redistributions of source code (Perl) must retain the above
   copyright notice, this list of conditions and the following disclaimer as the
   first lines of this file unmodified.

*  Redistributions in compiled form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   source code, documentation, and/or other materials provided with the 
   distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR(S) "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
